package
Version:
v0.0.0-...-31d4dac
Opens a new window with list of versions in this module.
Published: Mar 7, 2020
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Config struct {
DB database `toml:"database"`
}
Config defines the configuration for TOML file
type Metric struct {
Visits int `json:"url_visits"`
}
Metric structure for URL analytics
Source Files
¶
Click to show internal directories.
Click to hide internal directories.